## Step 1: Project Setup and Basic Test

In this step, we setup the basic structure and testing for our project.

### 1.1 Create a New Node.js Project
- Open your terminal.
- Navigate to the directory where you want to create your project.
- Run the following command to create a `package.json` file with default values:
```bash
npm init -y
```

### 1.2 Install Necessary Packages
- We will use `csv-parser` for CSV parsing and `jest` for testing. Install both packages using:
```bash
npm install csv-parser jest --save-dev
```

### 1.3 Create a Basic Project Structure
- Create a directory named `src`.
- Inside `src`, create a file named `index.js`. This will be your main file.

### 1.4 Configure Jest
- Add a Jest configuration to your `package.json` file. Add the following under the `scripts` section:
```json
"scripts": {
  "test": "jest"
}
```

- Create a directory named `tests` at the root of your project.
- Inside `tests`, create a file named `index.test.js` for your Jest tests.

### 1.5 Write a Basic Jest Test
- In `index.test.js`, write a simple test to check your Jest setup. Here's a basic test example:

```javascript
// tests/index.test.js

test('Basic Jest Test', () => {
  expect(1).toBe(1);
});
```

### 1.6 Run Your Jest Test
- To run the test, navigate to your project root in the terminal.
- Execute the test using the following command:

```bash
npm test
```

You should see the test passing in the console.
This completes the initial setup with Jest testing. Make sure everything works up to this point before moving to the next step.