## Step 2: Reading a CSV File

In this step we add the functionality to read from CSV files, since our DB would read from and write to CSV files, considering them as tables.

### 2.1 Create a Sample CSV File
Create a new CSV file in your project directory. Let's call it `sample.csv` and add some sample data to it:

```csv
id,name,age
1,John,30
2,Jane,25
3,Bob,22
```

### 2.2 Create a CSV Reading Function
- In the `src` directory, create a new file named `csvReader.js`.
- Implement a function to read the CSV file using `csv-parser`.

```javascript
// src/csvReader.js

const fs = require('fs');
const csv = require('csv-parser');

function readCSV(filePath) {
    const results = [];

    return new Promise((resolve, reject) => {
        fs.createReadStream(filePath)
            .pipe(csv())
            .on('data', (data) => results.push(data))
            .on('end', () => {
                resolve(results);
            })
            .on('error', (error) => {
                reject(error);
            });
    });
}

module.exports = readCSV;
```

### 2.3 Update Test to Check CSV Reading
Modify the test in `tests/index.test.js` to include a test for reading the CSV file.

Example test:

```javascript
// tests/index.test.js

const readCSV = require('../src/csvReader');

test('Read CSV File', async () => {
    const data = await readCSV('./sample.csv');
    expect(data.length).toBeGreaterThan(0);
    expect(data.length).toBe(3);
    expect(data[0].name).toBe('John');
    expect(data[0].age).toBe('30'); //ignore the string type here, we will fix this later
});
```

### 2.4 Run the Updated Test
Run the test using `npm test`. Ensure the test passes and correctly reads the CSV file.



