## Step 3: Building a Basic SQL Query Parser

In this section we will implement the basic functionality for our DB to make our DB understand SQL so that we can query data from it using SQL.

### 3.1 Create the Parser Function
In the `src` directory, create a new file named `queryParser.js`

Write a function that takes a SQL query string and parses it using regex to identify the `SELECT` fields and the `FROM` table name.

Example implementation:
```javascript
// src/queryParser.js

function parseQuery(query) {
    const selectRegex = /SELECT (.+) FROM (.+)/i;
    const match = query.match(selectRegex);

    if (match) {
        const [, fields, table] = match;
        return {
            fields: fields.split(',').map(field => field.trim()),
            table: table.trim()
        };
    } else {
        throw new Error('Invalid query format');
    }
}

module.exports = parseQuery;
```

### 3.2 Update Test to Check Query Parsing
Modify the test in `tests/index.test.js` to include a test for the SQL query parsing.
Example test:

```javascript
// tests/index.test.js

const parseQuery = require('../src/queryParser');

test('Parse SQL Query', () => {
    const query = 'SELECT id, name FROM sample';
    const parsed = parseQuery(query);
    expect(parsed).toEqual({
        fields: ['id', 'name'],
        table: 'sample'
    });
});
```
> **💡Do it yourself:** Try writing a test for the case the above function would throw an error.


### 3.3 Run the Updated Test
Run the test using `npm test`. Ensure the test passes and correctly parses the SQL query.
