## Step 4: Integrating CSV Reading with Query Parsing

In this step we integrate the functionalities implemented in the previous two steps together to get a basic `SELECT` query working in our DB.

### 4.1 Create the Query Execution Function
- In `src/index.js`, rename the function to `executeSELECTQuery` to indicate its specific purpose.
- Ensure the function handles only SELECT queries.
Here's a basic implementation:

```javascript
// src/index.js

const parseQuery = require('./queryParser');
const readCSV = require('./csvReader');

async function executeSELECTQuery(query) {
    const { fields, table } = parseQuery(query);
    const data = await readCSV(`${table}.csv`);
    
    // Filter the fields based on the query
    return data.map(row => {
        const filteredRow = {};
        fields.forEach(field => {
            filteredRow[field] = row[field];
        });
        return filteredRow;
    });
}

module.exports = executeSELECTQuery;
```

> **💡Do it yourself:** Find and list out conditions where this function can error out and handle them.

### 4.2 Update Test to Check Query Execution
Modify the test in `tests/index.test.js` to include a test for executing the SQL query.
Example test:

```javascript
// tests/index.test.js

const executeSELECTQuery = require('../src/index');

test('Execute SQL Query', async () => {
    const query = 'SELECT id, name FROM sample';
    const result = await executeSELECTQuery(query);
    expect(result.length).toBeGreaterThan(0);
    expect(result[0]).toHaveProperty('id');
    expect(result[0]).toHaveProperty('name');
    expect(result[0]).not.toHaveProperty('age');
    expect(result[0]).toEqual({ id: '1', name: 'John' });
});
```

### 4.3 Run the Updated Test
Run the test using `npm test`.
Ensure the test passes and correctly executes the SQL query, returning the filtered data.
