## Step 10: Implementing GROUP BY and Aggregate Functions

In this step we provide the much needed aggregation capabilities to our SQL engine by implementing support for `GROUP BY` and other aggregation functions.

### 10.1 Update the Parser to Handle GROUP BY Clauses
- Modify `queryParser.js` to parse `GROUP BY` clauses in the SQL query. The parser should identify the fields to group by.

Example snippet for updating `queryParser.js`:

```javascript
// src/queryParser.js

// ...existing code...

function parseQuery(query) {
    // ...existing parsing logic...

    // Updated regex to capture GROUP BY clause
    const groupByRegex = /\sGROUP BY\s(.+)/i;
    const groupByMatch = query.match(groupByRegex);

    let groupByFields = null;
    if (groupByMatch) {
        groupByFields = groupByMatch[1].split(',').map(field => field.trim());
    }

    return {
        // ...existing parsed parts,
        groupByFields
    };
}

// ...remaining code...

module.exports = { parseQuery, parseJoinClause };
```

> 💡**Do it yourself**: Update the `parseQuery` function based on the hints in the above code snippet.

### 10.2 Update the Execute Function to Apply GROUP BY and Aggregate Functions
- Modify `executeSELECTQuery` in `src/index.js` to perform grouping based on the `GROUP BY` clause and apply aggregate functions like `COUNT`, `SUM`, `AVG`, `MIN`, and `MAX`.

Example snippet for updating `executeSELECTQuery`:
```javascript
// src/index.js

// ...existing imports...

// Helper function to apply GROUP BY and aggregate functions
function applyGroupBy(data, groupByFields, aggregateFunctions) {
    // Implement logic to group data and calculate aggregates
    // ...
}

async function executeSELECTQuery(query) {
    const { fields, table, whereClauses, joinType, joinTable, joinCondition, groupByFields } = parseQuery(query);
    let data = await readCSV(`${table}.csv`);

    // ...existing logic for JOINs and WHERE clause...

    if (groupByFields) {
        data = applyGroupBy(data, groupByFields, fields);
    }

    // ...existing logic for field selection...
}

module.exports = executeSELECTQuery;
```

> 💡**Do it yourself**: Implement the `applyGroupBy` function and update the `executeSELECTQuery` function based on the hints in the above code snippet.

### 10.3 Add Tests for GROUP BY and Aggregate Functions
Update the test suite to include tests for queries using the `GROUP BY` clause and aggregate functions. [Commit for reference](https://github.com/ChakshuGautam/stylusdb-sql/commit/2df5a81650ce1f3846ec8e0b605aa2e7371dcf79)

> 💡 **Do it yourself**: Think of both negative and positive scenarios and make sure to cover all cases.