## Step 12: Implementing LIMIT Clause

In this step we add support to fetch only a specific number of records as a result of the SQL Query by implementing the `LIMIT` clause.

### 12.1 Update the Parser to Handle LIMIT Clauses
- Modify `queryParser.js` to parse `LIMIT` clauses in the SQL query.
The parser should identify the limit value.

Example snippet for updating `queryParser.js`:

```javascript
// src/queryParser.js

// ...existing code...

function parseQuery(query) {
    // ...existing parsing logic...

    // Updated regex to capture LIMIT clause
    const limitRegex = /\sLIMIT\s(\d+)/i;
    const limitMatch = query.match(limitRegex);

    let limit = null;
    if (limitMatch) {
        limit = parseInt(limitMatch[1]);
    }

    return {
        // ...existing parsed parts,
        limit
    };
}

// ...remaining code...

module.exports = { parseQuery, parseJoinClause };
```

> 💡 **Do it yourself**: Update the `parseQuery` function to add support for `LIMIT` clause with the help of hints in the above code snippet.

> 💡 **Ask yourself**: Is there some scope of refactoring in the above code snippet?

### 12.2 Update the Execute Function to Apply LIMIT
Modify `executeSELECTQuery` in `src/index.js` to apply the `LIMIT` clause on the result set.
Example snippet for updating `executeSELECTQuery`:

```javascript
// src/index.js

// ...existing imports and functions...

async function executeSELECTQuery(query) {
    const { fields, table, whereClauses, joinType, joinTable, joinCondition, groupByFields, orderByFields, limit } = parseQuery(query);
    let data = await readCSV(`${table}.csv`);

    // ...existing logic for JOINs, WHERE clause, GROUP BY, and ORDER BY...

    if (limit !== null) {
        data = data.slice(0, limit);
    }

    // ...existing logic for field selection...
}

module.exports = executeSELECTQuery;
```

> 💡 **Do it yourself**: Update the `executeSELECTQuery` function to add support for `LIMIT` clause with the help of hints in the above code snippet.

### 2.3 Add Tests for LIMIT Clause
- Update the test suite to include tests for queries using the `LIMIT` clause. [Commit for reference](https://github.com/ChakshuGautam/stylusdb-sql/commit/fd5ce77fd91e80655072fc6348d19d426fd12673)
