## Step 16: Adding CI Support

Let's add continuous integration (CI) support in our application using `GitHub actions` so that it auto runs the test on each commit to github and let's us know if something is off or is failing. 
> **💡Do it yourself**: Read more about CI/CD.

### 16.1 Setup directory
The code for Github Actions CI/CD resides inside the `.github/workflows` folder at the root of your project (github repository).

Create the folder either using the GUI of your editor/file manager or you can follow the steps below to create it using the command line.

```bash
cd /path/to/your/project/root
mkdir .github/workflows
```

### 16.2 Create a `tests.yml` file

Create a file named `tests.yml` in the `.github/workflows` directory and paste the below configuration.

```yaml
name: Run Tests

on:
  push:
    branches: [ main ]
  pull_request:
    branches: [ main ]

jobs:
  build:

    runs-on: ubuntu-latest

    strategy:
      matrix:
        node-version: [14.x, 16.x, 18.x]

    steps:
    - uses: actions/checkout@v3
    - name: Use Node.js ${{ matrix.node-version }}
      uses: actions/setup-node@v3
      with:
        node-version: ${{ matrix.node-version }}
    - run: npm i
    - run: npm test
```

### 16.3 Commit to github and see the tests passing

Commit this folder to your github repository which you must have created to submit your assignment and you will see the tests passing.

> **💡Do it yourself**: Look into toolings like `husky`.