## Basic INSERT Statement Support
In this exercise we will just support staments of the following format `INSERT INTO grades (student_id, course, grade) VALUES ('4', 'Physics', 'A')`.

### 17.1 Update the Query Parser
Add a function called `parseINSERTQuery` to the `queryParser.js` file. This function should take a query string as input and return an object with the following structure:

```javascript
{
      type: 'INSERT',
      table: 'grades',
      columns: [ 'student_id', 'course', 'grade' ],
      values: [ "'4'", "'Physics'", "'A'" ]
}
```

### 17.2 Update the Query Executer
Add a function called `executeINSERTQuery` to the `queryExecutor.js` file. This function should take a query object as input and insert the data into the CSV file. The function should return a promise that resolves to the number of rows inserted.


### 17.3. Make sure the following test passes

Create this test in a file called `tests/insertExecuter.test.js`

```javascript
const { executeINSERTQuery } = require('../src/queryExecutor');
const { readCSV, writeCSV } = require('../src/csvReader');
const fs = require('fs');

// Helper function to create grades.csv with initial data
async function createGradesCSV() {
    const initialData = [
        { student_id: '1', course: 'Mathematics', grade: 'A' },
        { student_id: '2', course: 'Chemistry', grade: 'B' },
        { student_id: '3', course: 'Mathematics', grade: 'C' }
    ];
    await writeCSV('grades.csv', initialData);
}

// Test to INSERT a new grade and verify
test('Execute INSERT INTO Query for grades.csv', async () => {
    // Create grades.csv with initial data
    await createGradesCSV();

    // Execute INSERT statement
    const insertQuery = "INSERT INTO grades (student_id, course, grade) VALUES ('4', 'Physics', 'A')";
    await executeINSERTQuery(insertQuery);

    // Verify the new entry
    const updatedData = await readCSV('grades.csv');
    const newEntry = updatedData.find(row => row.student_id === '4' && row.course === 'Physics');
    console.log(updatedData)
    expect(newEntry).toBeDefined();
    expect(newEntry.grade).toEqual('A');

    // Cleanup: Delete grades.csv
    fs.unlinkSync('grades.csv');
});
```

Note that there is some refactoring also done in this step which is reflected in the above test case. Make sure you make relevant changes to your code as well.