## Step 18: Implementing DELETE Statement Support

### 18.1 Update the Parser to Handle DELETE Statements
Modify `queryParser.js` to recognize `DELETE FROM` statements.
The parser should identify the table name and conditions for deletion.

It should return an object with the following structure:
```javascript
{
    type: 'DELETE',
    table: 'grades',
    whereClauses: [
        { column: 'student_id', operator: '=', value: "'4'" },
        { column: 'course', operator: '=', value: "'Physics'" }
    ]
}
```

### 18.2 Update the Executer to Handle DELETE Statements

```javascript
// src/queryExecutor.js

async function executeDELETEQuery(query) {
    const { table, whereClauses } = parseDeleteQuery(query);
    let data = await readCSV(`${table}.csv`);

    if (whereClauses.length > 0) {
        // Filter out the rows that meet the where clause conditions
        // Implement this.
    } else {
        // If no where clause, clear the entire table
        data = [];
    }

    // Save the updated data back to the CSV file
    await writeCSV(`${table}.csv`, data);

    return { message: "Rows deleted successfully." };
}

module.exports = { executeSELECTQuery, executeINSERTQuery, executeDELETEQuery };
```

### 18.3 Make sure the following test passes

Create this test in a file called `tests/deleteExecuter.test.js`

```javascript
const { executeDELETEQuery } = require('../src/queryExecutor');
const { readCSV, writeCSV } = require('../src/csvReader');
const fs = require('fs');

// Helper function to create courses.csv with initial data
async function createCoursesCSV() {
    const initialData = [
        { course_id: '1', course_name: 'Mathematics', instructor: 'Dr. Smith' },
        { course_id: '2', course_name: 'Chemistry', instructor: 'Dr. Jones' },
        { course_id: '3', course_name: 'Physics', instructor: 'Dr. Taylor' }
    ];
    await writeCSV('courses.csv', initialData);
}

// Test to DELETE a course and verify
test('Execute DELETE FROM Query for courses.csv', async () => {
    // Create courses.csv with initial data
    await createCoursesCSV();

    // Execute DELETE statement
    const deleteQuery = "DELETE FROM courses WHERE course_id = '2'";
    await executeDELETEQuery(deleteQuery);

    // Verify the course was removed
    const updatedData = await readCSV('courses.csv');
    const deletedCourse = updatedData.find(course => course.course_id === '2');
    expect(deletedCourse).toBeUndefined();

    // Cleanup: Delete courses.csv
    fs.unlinkSync('courses.csv');
});
```
